==> dotenv-parse-variables-2.0.1.tgz: dotenv-parse-variables/README.md <==
# Installation
> `npm install --save @types/dotenv-parse-variables`

# Summary
This package contains type definitions for dotenv-parse-variables (https://github.com/niftylettuce/dotenv-parse-variables).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/dotenv-parse-variables.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/dotenv-parse-variables/index.d.ts)
````ts
// Type definitions for dotenv-parse-variables 2.0
// Project: https://github.com/niftylettuce/dotenv-parse-variables
// Definitions by: Gary King <https://github.com/garyking>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

declare namespace dotenvParseVariables {
    type Parsed = Record<string, string>;

    interface Options {
        /**
         * whether or not to assign the parsed values to `process.env`
         * @default true
         */
        assignToProcessEnv?: boolean | undefined;
        /**
         * whether or not to override existing values in `process.env`
         * @default false
         */
        overrideProcessEnv?: boolean | undefined;
        /**
         * whether or not to ignore functions in the parsed values returned
         * @default true
         */
        ignoreFunctions?: boolean | undefined;
    }

    type ParsedVariables = Record<string, unknown>;
}

declare function dotenvParseVariables(
    parsed: dotenvParseVariables.Parsed,
    options?: dotenvParseVariables.Options,
): dotenvParseVariables.ParsedVariables;

export = dotenvParseVariables;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 09:08:52 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Gary King](https://github.com/garyking).

==> dotenv-parse-variables-2.0.2.tgz: dotenv-parse-variables/README.md <==
# Installation
> `npm install --save @types/dotenv-parse-variables`

# Summary
This package contains type definitions for dotenv-parse-variables (https://github.com/niftylettuce/dotenv-parse-variables).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/dotenv-parse-variables.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/dotenv-parse-variables/index.d.ts)
````ts
declare namespace dotenvParseVariables {
    type Parsed = Record<string, string>;

    interface Options {
        /**
         * whether or not to assign the parsed values to `process.env`
         * @default true
         */
        assignToProcessEnv?: boolean | undefined;
        /**
         * whether or not to override existing values in `process.env`
         * @default false
         */
        overrideProcessEnv?: boolean | undefined;
        /**
         * whether or not to ignore functions in the parsed values returned
         * @default true
         */
        ignoreFunctions?: boolean | undefined;
    }

    type ParsedVariables = Record<string, unknown>;
}

declare function dotenvParseVariables(
    parsed: dotenvParseVariables.Parsed,
    options?: dotenvParseVariables.Options,
): dotenvParseVariables.ParsedVariables;

export = dotenvParseVariables;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:34 GMT
 * Dependencies: none

# Credits
These definitions were written by [Gary King](https://github.com/garyking).
